@@ -14,13 +14,11 @@ from vespa.package import (
     SecondPhaseRanking,
     RankProfile,
     ApplicationPackage,
-    ModelServer,
     QueryProfile,
     QueryProfileType,
-    QueryTypeField
+    QueryTypeField,
 )
 from vespa.deployment import VespaDocker
-from vespa.ml import BertModelConfig, SequenceClassification
 from vespa.application import VespaSync
 from learntorank.query import (
     QueryModel,
@@ -30,6 +28,12 @@ from learntorank.query import (
     send_query,
     store_vespa_features,
 )
+from learntorank.ml import (
+    SequenceClassification,
+    BertModelConfig,
+    ModelServer,
+    add_ranking_model,
+)
 
 CONTAINER_STOP_TIMEOUT = 600
 
@@ -105,7 +109,8 @@ def create_cord19_application_package():
         query_input_size=5,
         doc_input_size=10,
     )
-    app_package.add_model_ranking(
+    add_ranking_model(
+        app_package=app_package,
         model_config=bert_config,
         include_model_summary_features=True,
         inherits="default",
@@ -232,13 +237,6 @@ class TestDockerCommon(unittest.TestCase):
             self.vespa_docker.deploy(application_package=application_package)
         except RuntimeError as e:
             assert False, "Deployment error: {}".format(e)
-        #
-        # Test VespaDocker serialization
-        #
-        self.assertEqual(
-            repr(self.vespa_docker),
-            repr(VespaDocker.from_dict(self.vespa_docker.to_dict)),
-        )
 
     def create_vespa_docker_from_container_name_or_id(self, application_package):
         #
