@@ -5,7 +5,7 @@ from torch import Tensor
 from transformers import BertForSequenceClassification
 from numpy.testing import assert_almost_equal
 
-from vespa.ml import BertModelConfig
+from learntorank.ml import BertModelConfig
 
 
 class TestBertModelConfigTokenizerOnly(unittest.TestCase):
@@ -17,11 +17,6 @@ class TestBertModelConfigTokenizerOnly(unittest.TestCase):
             tokenizer=os.path.join(os.environ["RESOURCES_DIR"], "bert_tiny_tokenizer"),
         )
 
-    def test_serialization(self):
-        self.assertEqual(
-            self.model_config, BertModelConfig.from_dict(self.model_config.to_dict)
-        )
-
     def test_add_model(self):
         self.assertIsNone(self.model_config.model)
         self.assertIsNone(self.model_config._model)
@@ -99,11 +94,6 @@ class TestBertModelConfig(unittest.TestCase):
             model=os.path.join(os.environ["RESOURCES_DIR"], "bert_tiny_model"),
         )
 
-    def test_serialization(self):
-        self.assertEqual(
-            self.model_config, BertModelConfig.from_dict(self.model_config.to_dict)
-        )
-
     def test_predict(self):
         prediction = self.model_config.predict(
             queries=["this is one query", "this is another query"],
