@@ -20,9 +20,8 @@ from vespa.package import (
     QueryField,
     QueryProfile,
     ApplicationPackage,
-    ModelServer
 )
-from vespa.ml import BertModelConfig
+from learntorank.ml import BertModelConfig, ModelServer, add_ranking_model
 
 
 class TestField(unittest.TestCase):
@@ -30,9 +29,7 @@ class TestField(unittest.TestCase):
         field = Field(name="test_name", type="string")
         self.assertEqual(field.name, "test_name")
         self.assertEqual(field.type, "string")
-        self.assertEqual(field.to_dict, {"name": "test_name", "type": "string"})
         self.assertEqual(field, Field(name="test_name", type="string"))
-        self.assertEqual(field, Field.from_dict(field.to_dict))
         self.assertIsNone(field.indexing_to_text)
 
     def test_field_name_type_indexing_index(self):
@@ -46,15 +43,6 @@ class TestField(unittest.TestCase):
         self.assertEqual(field.type, "string")
         self.assertEqual(field.indexing, ["index", "summary"])
         self.assertEqual(field.index, "enable-bm25")
-        self.assertEqual(
-            field.to_dict,
-            {
-                "name": "body",
-                "type": "string",
-                "indexing": ["index", "summary"],
-                "index": "enable-bm25",
-            },
-        )
         self.assertEqual(
             field,
             Field(
@@ -64,23 +52,8 @@ class TestField(unittest.TestCase):
                 index="enable-bm25",
             ),
         )
-        self.assertEqual(field, Field.from_dict(field.to_dict))
         self.assertEqual(field.indexing_to_text, "index | summary")
 
-    def test_tensor_with_hnsw(self):
-        field = Field(
-            name="tensor_field",
-            type="tensor<float>(x[128])",
-            indexing=["attribute"],
-            attribute=["fast-search", "fast-access"],
-            ann=HNSW(
-                distance_metric="euclidean",
-                max_links_per_node=16,
-                neighbors_to_explore_at_insert=200,
-            ),
-        )
-        self.assertEqual(field, Field.from_dict(field.to_dict))
-
 
 class TestImportField(unittest.TestCase):
     def test_import_field(self):
@@ -92,24 +65,18 @@ class TestImportField(unittest.TestCase):
         self.assertEqual(imported_field.name, "global_category_ctrs")
         self.assertEqual(imported_field.reference_field, "category_ctr_ref")
         self.assertEqual(imported_field.field_to_import, "ctrs")
-        self.assertEqual(
-            imported_field, ImportedField.from_dict(imported_field.to_dict)
-        )
 
 
 class TestDocument(unittest.TestCase):
     def test_empty_document(self):
         document = Document()
         self.assertEqual(document.fields, [])
-        self.assertEqual(document.to_dict, {"fields": [], "inherits": None})
-        self.assertEqual(document, Document.from_dict(document.to_dict))
 
     def test_document_one_field(self):
         document = Document(inherits="context")
         field = Field(name="test_name", type="string")
         document.add_fields(field)
         self.assertEqual(document.fields, [field])
-        self.assertEqual(document, Document.from_dict(document.to_dict))
         self.assertEqual(document, Document([field], "context"))
 
     def test_document_two_fields(self):
@@ -123,7 +90,6 @@ class TestDocument(unittest.TestCase):
         )
         document.add_fields(field_1, field_2)
         self.assertEqual(document.fields, [field_1, field_2])
-        self.assertEqual(document, Document.from_dict(document.to_dict))
         self.assertEqual(document, Document([field_1, field_2]))
 
     def test_update_field(self):
@@ -143,21 +109,9 @@ class TestFieldSet(unittest.TestCase):
         field_set = FieldSet(name="default", fields=["title", "body"])
         self.assertEqual(field_set.name, "default")
         self.assertEqual(field_set.fields, ["title", "body"])
-        self.assertEqual(field_set, FieldSet.from_dict(field_set.to_dict))
         self.assertEqual(field_set.fields_to_text, "title, body")
 
 
-class TestSecondPhaseRanking(unittest.TestCase):
-    def test_second_phase_ranking(self):
-        second_phase_ranking = SecondPhaseRanking(
-            expression="sum(eval)", rerank_count=10
-        )
-        self.assertEqual(
-            second_phase_ranking,
-            SecondPhaseRanking.from_dict(second_phase_ranking.to_dict),
-        )
-
-
 class TestFunction(unittest.TestCase):
     def test_function_no_argument(self):
         function = Function(
@@ -167,7 +121,6 @@ class TestFunction(unittest.TestCase):
         self.assertEqual(
             function.expression, "fieldMatch(title) + freshness(timestamp)"
         )
-        self.assertEqual(function, Function.from_dict(function.to_dict))
         self.assertEqual(function.args_to_text, "")
 
     def test_function_one_argument(self):
@@ -179,7 +132,6 @@ class TestFunction(unittest.TestCase):
         self.assertEqual(function.name, "myfeature")
         self.assertEqual(function.expression, "fieldMatch(title) + freshness(foo)")
         self.assertEqual(function.args, ["foo"])
-        self.assertEqual(function, Function.from_dict(function.to_dict))
         self.assertEqual(function.args_to_text, "foo")
 
     def test_function_multiple_argument(self):
@@ -191,7 +143,6 @@ class TestFunction(unittest.TestCase):
         self.assertEqual(function.name, "myfeature")
         self.assertEqual(function.expression, "fieldMatch(bar) + freshness(foo)")
         self.assertEqual(function.args, ["foo", "bar"])
-        self.assertEqual(function, Function.from_dict(function.to_dict))
         self.assertEqual(function.args_to_text, "foo, bar")
 
     def test_function_multiple_lines(self):
@@ -221,7 +172,6 @@ class TestFunction(unittest.TestCase):
             """,
         )
         self.assertEqual(function.args, None)
-        self.assertEqual(function, Function.from_dict(function.to_dict))
         self.assertEqual(function.args_to_text, "")
 
 
@@ -230,7 +180,6 @@ class TestRankProfile(unittest.TestCase):
         rank_profile = RankProfile(name="bm25", first_phase="bm25(title) + bm25(body)")
         self.assertEqual(rank_profile.name, "bm25")
         self.assertEqual(rank_profile.first_phase, "bm25(title) + bm25(body)")
-        self.assertEqual(rank_profile, RankProfile.from_dict(rank_profile.to_dict))
 
     def test_rank_profile_inherits(self):
         rank_profile = RankProfile(
@@ -238,7 +187,6 @@ class TestRankProfile(unittest.TestCase):
         )
         self.assertEqual(rank_profile.name, "bm25")
         self.assertEqual(rank_profile.first_phase, "bm25(title) + bm25(body)")
-        self.assertEqual(rank_profile, RankProfile.from_dict(rank_profile.to_dict))
 
     def test_rank_profile_bert_second_phase(self):
         rank_profile = RankProfile(
@@ -306,25 +254,6 @@ class TestRankProfile(unittest.TestCase):
             rank_profile.summary_features,
             ["onnx(bert).logits", "input_ids", "attention_mask", "token_type_ids"],
         )
-        self.assertEqual(rank_profile, RankProfile.from_dict(rank_profile.to_dict))
-
-
-class TestOnnxModel(unittest.TestCase):
-    def test_onnx_model(self):
-        onnx_model = OnnxModel(
-            model_name="bert",
-            model_file_path="bert.onnx",
-            inputs={
-                "input_ids": "input_ids",
-                "token_type_ids": "token_type_ids",
-                "attention_mask": "attention_mask",
-            },
-            outputs={"logits": "logits"},
-        )
-        self.assertEqual(
-            onnx_model,
-            OnnxModel.from_dict(onnx_model.to_dict),
-        )
 
 
 class TestSchema(unittest.TestCase):
@@ -358,9 +287,6 @@ class TestSchema(unittest.TestCase):
             ],
         )
 
-    def test_serialization(self):
-        self.assertEqual(self.schema, Schema.from_dict(self.schema.to_dict))
-
     def test_rank_profile(self):
         self.assertDictEqual(
             self.schema.rank_profiles,
@@ -419,28 +345,19 @@ class TestQueryTypeField(unittest.TestCase):
         field = QueryTypeField(name="test_name", type="string")
         self.assertEqual(field.name, "test_name")
         self.assertEqual(field.type, "string")
-        self.assertEqual(field.to_dict, {"name": "test_name", "type": "string"})
         self.assertEqual(field, QueryTypeField(name="test_name", type="string"))
-        self.assertEqual(field, QueryTypeField.from_dict(field.to_dict))
 
 
 class TestQueryProfileType(unittest.TestCase):
     def test_empty(self):
         query_profile_type = QueryProfileType()
         self.assertEqual(query_profile_type.fields, [])
-        self.assertEqual(query_profile_type.to_dict, {"fields": []})
-        self.assertEqual(
-            query_profile_type, QueryProfileType.from_dict(query_profile_type.to_dict)
-        )
 
     def test_one_field(self):
         query_profile_type = QueryProfileType()
         field = QueryTypeField(name="test_name", type="string")
         query_profile_type.add_fields(field)
         self.assertEqual(query_profile_type.fields, [field])
-        self.assertEqual(
-            query_profile_type, QueryProfileType.from_dict(query_profile_type.to_dict)
-        )
         self.assertEqual(query_profile_type, QueryProfileType([field]))
 
     def test_two_fields(self):
@@ -452,9 +369,6 @@ class TestQueryProfileType(unittest.TestCase):
         )
         query_profile_type.add_fields(field_1, field_2)
         self.assertEqual(query_profile_type.fields, [field_1, field_2])
-        self.assertEqual(
-            query_profile_type, QueryProfileType.from_dict(query_profile_type.to_dict)
-        )
         self.assertEqual(query_profile_type, QueryProfileType([field_1, field_2]))
 
 
@@ -463,24 +377,19 @@ class TestQueryField(unittest.TestCase):
         field = QueryField(name="test_name", value=1)
         self.assertEqual(field.name, "test_name")
         self.assertEqual(field.value, 1)
-        self.assertEqual(field.to_dict, {"name": "test_name", "value": 1})
         self.assertEqual(field, QueryField(name="test_name", value=1))
-        self.assertEqual(field, QueryField.from_dict(field.to_dict))
 
 
 class TestQueryProfile(unittest.TestCase):
     def test_empty(self):
         query_profile = QueryProfile()
         self.assertEqual(query_profile.fields, [])
-        self.assertEqual(query_profile.to_dict, {"fields": []})
-        self.assertEqual(query_profile, QueryProfile.from_dict(query_profile.to_dict))
 
     def test_one_field(self):
         query_profile = QueryProfile()
         field = QueryField(name="test_name", value=2.0)
         query_profile.add_fields(field)
         self.assertEqual(query_profile.fields, [field])
-        self.assertEqual(query_profile, QueryProfile.from_dict(query_profile.to_dict))
         self.assertEqual(query_profile, QueryProfile([field]))
 
     def test_two_fields(self):
@@ -492,7 +401,6 @@ class TestQueryProfile(unittest.TestCase):
         )
         query_profile.add_fields(field_1, field_2)
         self.assertEqual(query_profile.fields, [field_1, field_2])
-        self.assertEqual(query_profile, QueryProfile.from_dict(query_profile.to_dict))
         self.assertEqual(query_profile, QueryProfile([field_1, field_2]))
 
 
@@ -622,11 +530,6 @@ class TestApplicationPackage(unittest.TestCase):
             query_profile_type=test_query_profile_type,
         )
 
-    def test_application_package(self):
-        self.assertEqual(
-            self.app_package, ApplicationPackage.from_dict(self.app_package.to_dict)
-        )
-
     def test_get_schema(self):
         self.assertEqual(self.app_package.schema, self.test_schema)
         self.assertEqual(self.app_package.schema, self.app_package.get_schema())
@@ -835,11 +738,6 @@ class TestApplicationPackageMultipleSchema(unittest.TestCase):
             schema=[self.news_schema, self.user_schema, self.category_ctr_schema],
         )
 
-    def test_application_package(self):
-        self.assertEqual(
-            self.app_package, ApplicationPackage.from_dict(self.app_package.to_dict)
-        )
-
     def test_get_schema(self):
         self.assertEqual(self.app_package.get_schema(name="news"), self.news_schema)
         self.assertEqual(self.app_package.get_schema(name="user"), self.user_schema)
@@ -952,7 +850,8 @@ class TestApplicationPackageAddBertRankingWithMultipleSchemas(unittest.TestCase)
             tokenizer=os.path.join(os.environ["RESOURCES_DIR"], "bert_tiny_tokenizer"),
             model=os.path.join(os.environ["RESOURCES_DIR"], "bert_tiny_model"),
         )
-        self.app_package.add_model_ranking(
+        add_ranking_model(
+            self.app_package,
             model_config=bert_config,
             schema="news",
             include_model_summary_features=True,
@@ -963,11 +862,6 @@ class TestApplicationPackageAddBertRankingWithMultipleSchemas(unittest.TestCase)
 
         self.disk_folder = "saved_app"
 
-    def test_application_package(self):
-        self.assertEqual(
-            self.app_package, ApplicationPackage.from_dict(self.app_package.to_dict)
-        )
-
     def test_news_schema_to_text(self):
         expected_result = (
             "schema news {\n"
@@ -1100,12 +994,6 @@ class TestApplicationPackageAddBertRankingWithMultipleSchemas(unittest.TestCase)
         )
         self.assertEqual(self.app_package.query_profile_type_to_text, expected_result)
 
-    def test_save_load(self):
-        self.app_package.save(disk_folder=self.disk_folder)
-        self.assertEqual(
-            self.app_package, ApplicationPackage.load(disk_folder=self.disk_folder)
-        )
-
     def tearDown(self) -> None:
         rmtree(self.disk_folder, ignore_errors=True)
 
@@ -1164,11 +1052,6 @@ class TestSimplifiedApplicationPackage(unittest.TestCase):
             QueryField(name="anotherField", value="string_value"),
         )
 
-    def test_application_package(self):
-        self.assertEqual(
-            self.app_package, ApplicationPackage.from_dict(self.app_package.to_dict)
-        )
-
     def test_schema_to_text(self):
         expected_result = (
             "schema testapp {\n"
@@ -1279,11 +1162,6 @@ class TestSimplifiedApplicationPackageWithMultipleSchemas(unittest.TestCase):
             )
         )
 
-    def test_application_package(self):
-        self.assertEqual(
-            self.app_package, ApplicationPackage.from_dict(self.app_package.to_dict)
-        )
-
     def test_schema_to_text(self):
         expected_news_result = (
             "schema news {\n"
@@ -1382,7 +1260,8 @@ class TestSimplifiedApplicationPackageAddBertRanking(unittest.TestCase):
             model=os.path.join(os.environ["RESOURCES_DIR"], "bert_tiny_model"),
         )
 
-        self.app_package.add_model_ranking(
+        add_ranking_model(
+            self.app_package,
             model_config=bert_config,
             include_model_summary_features=True,
             inherits="default",
@@ -1391,11 +1270,6 @@ class TestSimplifiedApplicationPackageAddBertRanking(unittest.TestCase):
         )
         self.disk_folder = "saved_app"
 
-    def test_application_package(self):
-        self.assertEqual(
-            self.app_package, ApplicationPackage.from_dict(self.app_package.to_dict)
-        )
-
     def test_schema_to_text(self):
         expected_result = (
             "schema testapp {\n"
@@ -1536,18 +1410,11 @@ class TestSimplifiedApplicationPackageAddBertRanking(unittest.TestCase):
         )
         self.assertEqual(self.app_package.query_profile_type_to_text, expected_result)
 
-    def test_save_load(self):
-        self.app_package.save(disk_folder=self.disk_folder)
-        self.assertEqual(
-            self.app_package, ApplicationPackage.load(disk_folder=self.disk_folder)
-        )
-
     def tearDown(self) -> None:
         rmtree(self.disk_folder, ignore_errors=True)
 
 
 class TestValidAppName(unittest.TestCase):
-
     def test_invalid_name(self):
         with pytest.raises(ValueError):
             app_package = ApplicationPackage(name="test_app")
